headers method
Returns headers specific to this request, or null for none.
These are merged on top of the connector's Connector.defaultHeaders, with request values taking priority.
Implementation
Map<String, String>? headers() => null;
Returns headers specific to this request, or null for none.
These are merged on top of the connector's Connector.defaultHeaders, with request values taking priority.
Map<String, String>? headers() => null;