logRequest property

bool get logRequest

Whether the outgoing request should be passed to the logging interceptor.

Defaults to true. Set to false to suppress logging for this particular request (e.g. for requests carrying sensitive credentials).

Implementation

bool get logRequest => true;