logResponse property

bool get logResponse

Whether the incoming response should be passed to the logging interceptor.

Defaults to true. Set to false to suppress response logging for this particular request.

Implementation

bool get logResponse => true;