UnauthorizedException class

Exception thrown when the server returns a 401 Unauthorized response.

Thrown by Connector.send when the request lacks valid authentication credentials. The statusCode is always 401.

Inheritance

Constructors

UnauthorizedException(String message)
Creates an UnauthorizedException with the given error message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The human-readable error message.
finalinherited
response LuckyResponse?
The LuckyResponse that triggered this exception, if available.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code associated with this error, if available.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited