errors property

Map<String, dynamic>? errors
final

A map of field names to their associated validation error messages.

May be null if the server did not return structured error data.

Implementation

final Map<String, dynamic>? errors;